summaryrefslogtreecommitdiffstats
path: root/libk3b/plugin/k3baudioencoder.h
diff options
context:
space:
mode:
Diffstat (limited to 'libk3b/plugin/k3baudioencoder.h')
-rw-r--r--libk3b/plugin/k3baudioencoder.h37
1 files changed, 19 insertions, 18 deletions
diff --git a/libk3b/plugin/k3baudioencoder.h b/libk3b/plugin/k3baudioencoder.h
index 137b49d..b3fc01b 100644
--- a/libk3b/plugin/k3baudioencoder.h
+++ b/libk3b/plugin/k3baudioencoder.h
@@ -33,9 +33,10 @@
class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
{
Q_OBJECT
+ TQ_OBJECT
public:
- K3bAudioEncoder( QObject* parent = 0, const char* name = 0 );
+ K3bAudioEncoder( TQObject* tqparent = 0, const char* name = 0 );
virtual ~K3bAudioEncoder();
// TODO: if the following methods are to be activated the config methods in
@@ -52,7 +53,7 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
*/
// virtual void readConfig( KConfig* );
- QString group() const { return "AudioEncoder"; }
+ TQString group() const { return "AudioEncoder"; }
/**
* This should return the fileextensions supported by the filetype written in the
@@ -61,19 +62,19 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
* in handy if the encoder is based on some external program or lib which is not
* available on runtime.)
*/
- virtual QStringList extensions() const = 0;
+ virtual TQStringList extensions() const = 0;
/**
* The filetype as presented to the user.
*/
- virtual QString fileTypeComment( const QString& extension ) const = 0;
+ virtual TQString fileTypeComment( const TQString& extension ) const = 0;
/**
* Determine the filesize of the encoded file (~)
* default implementation returnes -1 (unknown)
* First parameter is the extension to be used
*/
- virtual long long fileSize( const QString&, const K3b::Msf& ) const { return -1; }
+ virtual long long fileSize( const TQString&, const K3b::Msf& ) const { return -1; }
/**
* The default implementation openes the file for writing with
@@ -81,7 +82,7 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
* @param extension the filetype to be used.
*
*/
- virtual bool openFile( const QString& extension, const QString& filename, const K3b::Msf& length );
+ virtual bool openFile( const TQString& extension, const TQString& filename, const K3b::Msf& length );
/**
@@ -101,11 +102,11 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
/**
* The default implementation returnes the filename set in openFile
* or QString::null if no file has been opened.
* Normally this does not need to be reimplemented but it has to be
* if openFile is reimplemented.
*/
- virtual const QString& filename() const;
+ virtual const TQString& filename() const;
enum MetaDataField {
META_TRACK_TITLE,
@@ -123,7 +124,7 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
* calling openFile and before calling encode.
* This calls setMetaDataInternal.
*/
- void setMetaData( MetaDataField, const QString& );
+ void setMetaData( MetaDataField, const TQString& );
/**
* Returnes the amount of actually written bytes or -1 if an error
@@ -132,20 +133,20 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
* Be aware that the returned amount of written data may very well differ
* from len since the data is encoded.
*/
- long encode( const char*, Q_ULONG len );
+ long encode( const char*, TQ_ULONG len );
/**
* Use this signal in case of an error to provide the user with information
* about the problem.
*/
- virtual QString lastErrorString() const;
+ virtual TQString lastErrorString() const;
protected:
/**
* Called by the default implementation of openFile
* This calls initEncoderInternal.
*/
- bool initEncoder( const QString& extension, const K3b::Msf& length );
+ bool initEncoder( const TQString& extension, const K3b::Msf& length );
/**
* Called by the deafult implementation of openFile
@@ -158,14 +159,14 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
* using the default implementation of openFile
* Returnes the number of bytes actually written.
*/
- Q_LONG writeData( const char*, Q_ULONG len );
+ TQ_LONG writeData( const char*, TQ_ULONG len );
/**
* initzialize the decoder structures.
* default implementation does nothing
* this may already write data.
*/
- virtual bool initEncoderInternal( const QString& extension, const K3b::Msf& length );
+ virtual bool initEncoderInternal( const TQString& extension, const K3b::Msf& length );
/**
* reimplement this if the encoder needs to do some
@@ -180,20 +181,20 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
* Should return the amount of actually written bytes (may be 0) and -1
* on error.
*/
- // TODO: use Q_INT16* instead of char*
+ // TODO: use TQ_INT16* instead of char*
// FIXME: why little endian while CDs use big endian???
- virtual long encodeInternal( const char*, Q_ULONG len ) = 0;
+ virtual long encodeInternal( const char*, TQ_ULONG len ) = 0;
/**
* default implementation does nothing
* this may already write data.
*/
- virtual void setMetaDataInternal( MetaDataField, const QString& );
+ virtual void setMetaDataInternal( MetaDataField, const TQString& );
/**
* Use this in combination with the default implementation of lastError()
*/
- void setLastError( const QString& );
+ void setLastError( const TQString& );
private:
class Private;
@@ -101,11 +102,11 @@ class LIBK3B_EXPORT K3bAudioEncoder : public K3bPlugin
/**
* The default implementation returnes the filename set in openFile
- * or QString::null if no file has been opened.
+ * or TQString() if no file has been opened.
* Normally this does not need to be reimplemented but it has to be
* if openFile is reimplemented.